@@ -28,23 +28,30 @@ class LessonStatisticsView : public ContainerView
 
 public:
     LessonStatisticsView(QWidget *parent);
+    ~LessonStatisticsView();
     void setModel(ContainerModel *model) Q_DECL_OVERRIDE;
+    void saveExpandedStatus() const;
+    void restoreExpandedStatus();
 
-private Q_SLOTS:
-    void removeGrades();
-    void removeGradesChildren();
+public Q_SLOTS:
+    void adjustColumnWidths();
 
 protected:
     void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
+    void removeGrades();
+    void removeGradesChildren();
     void sectionResized(int index, int /*oldSize*/, int /*newSize*/);
-    void adjustColumnWidths();
 
 private:
     void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE {
         Q_UNUSED(model)
     }
+    void getCollapsedItems(QStringList &collapsedItems, const QModelIndex &item,
+                           QString name) const;
+    void setCollapsedItems(const QStringList &collapsedItems, const QModelIndex &item,
+                           QString name);
 };
 
 #endif
